@@ -136,9 +136,10 @@ impl<'a> Sorter<'a> {
 #[cfg(test)]
 mod tests {
     use crate::sorter::Sorter;
+    use crate::tuner::Algorithm;
     use crate::tuners::StandardTuner;
     use crate::utils::get_counts;
-    use crate::utils::test_utils::{sort_comparison_suite, NumericTest};
+    use crate::utils::test_utils::{sort_comparison_suite, sort_single_algorithm, NumericTest};
 
     fn test_lsb_sort_adapter<T>(shift: T)
     where
@@ -188,4 +189,14 @@ mod tests {
     pub fn test_usize() {
         test_lsb_sort_adapter(32usize);
     }
+
+    #[test]
+    pub fn test_basic_integration() {
+        sort_single_algorithm::<u32>(1_000_000, Algorithm::Lsb);
+    }
+
+    #[test]
+    pub fn test_basic_integration_lr() {
+        sort_single_algorithm::<u32>(1_000_000, Algorithm::LrLsb);
+    }
 }
