@@ -215,9 +215,10 @@ impl<'a> Sorter<'a> {
 #[cfg(test)]
 mod tests {
     use crate::sorter::Sorter;
+    use crate::tuner::Algorithm;
     use crate::tuners::StandardTuner;
     use crate::utils::cdiv;
-    use crate::utils::test_utils::{sort_comparison_suite, NumericTest};
+    use crate::utils::test_utils::{sort_comparison_suite, sort_single_algorithm, NumericTest};
     use rayon::current_num_threads;
 
     fn test_mt_lsb_sort_adapter<T>(shift: T)
@@ -266,4 +267,9 @@ mod tests {
     pub fn test_usize() {
         test_mt_lsb_sort_adapter(32usize);
     }
+
+    #[test]
+    pub fn test_basic_integration() {
+        sort_single_algorithm::<u32>(1_000_000, Algorithm::MtLsb);
+    }
 }
