@@ -113,9 +113,10 @@ impl<'a> Sorter<'a> {
 #[cfg(test)]
 mod tests {
     use crate::sorter::Sorter;
+    use crate::tuner::Algorithm;
     use crate::tuners::StandardTuner;
     use crate::utils::get_counts;
-    use crate::utils::test_utils::{sort_comparison_suite, NumericTest};
+    use crate::utils::test_utils::{sort_comparison_suite, sort_single_algorithm, NumericTest};
 
     fn test_ska_sort_adapter<T>(shift: T)
     where
@@ -159,4 +160,9 @@ mod tests {
     pub fn test_usize() {
         test_ska_sort_adapter(32usize);
     }
+
+    #[test]
+    pub fn test_basic_integration() {
+        sort_single_algorithm::<u32>(1_000_000, Algorithm::Ska);
+    }
 }
